@@ -14,16 +14,16 @@ def ask_yes_no(message, default=None):
         Thanks to this useful recipe for help:
             http://code.activestate.com/recipes/577058/
     """
-    valid = {"yes": True,
-             "y": True,
-             "ye": True,
-             "no": False,
-             "n": False}
+    valid = {'yes': True,
+             'y': True,
+             'ye': True,
+             'no': False,
+             'n': False}
     if default:
-        prompt = " [Y/n] "
+        prompt = ' [Y/n] '
         valid[''] = True
     else:
-        prompt = " [y/N] "
+        prompt = ' [y/N] '
         valid[''] = False
 
     while True:
@@ -55,20 +55,24 @@ def determine_directories(name, basedir, snap=False):
     project['directories'] = [project['project_dir']]
 
     if not snap:
-        if ask_yes_no("Would you like a bin directory?", default=True):
-            project['bin_dir'] = join(project['project_dir'], "bin")
+        if (not os.path.isdir(join(project['project_dir'], 'bin')) and
+                ask_yes_no("Would you like a bin directory?", default=True)):
+            project['bin_dir'] = join(project['project_dir'], 'bin')
             project['directories'].append(project['bin_dir'])
 
-        if ask_yes_no("Would you like a tests directory?", default=True):
-            project['tests_dir'] = join(project['project_dir'], "tests")
+        if (not os.path.isdir(join(project['project_dir'], 'tests')) and
+                ask_yes_no("Would you like a tests directory?", default=True)):
+            project['tests_dir'] = join(project['project_dir'], 'tests')
             project['directories'].append(project['tests_dir'])
     else:
-        project['bin_dir'] = join(project['project_dir'], "bin")
-        project['tests_dir'] = join(project['project_dir'], "tests")
-        project['directories'].extend([project['bin_dir'],
-                                       project['tests_dir']])
+        if not os.path.isdir(join(project['project_dir'], 'bin')):
+            project['bin_dir'] = join(project['project_dir'], 'bin')
+            project['directories'].append(project['bin_dir'])
+        if not os.path.isdir(join(project['project_dir'], 'tests')):
+            project['tests_dir'] = join(project['project_dir'], 'tests')
+            project['directories'].append(project['tests_dir'])
 
-    project['docs_dir'] = join(project['project_dir'], "docs")
+    project['docs_dir'] = join(project['project_dir'], 'docs')
     project['source_dir'] = join(project['project_dir'], name)
 
     project['directories'].extend([project['docs_dir'], project['source_dir']])
